package app.insti.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.squareup.picasso.Picasso;

import java.util.List;

import app.insti.R;
import app.insti.api.model.MyEvent;
import app.insti.api.model.SubActivity;

public class MyEventAdapter extends RecyclerView.Adapter<MyEventAdapter.MyEventViewHolder> {

    private Context context;
    private List<MyEvent> myEventList;

    public MyEventAdapter(Context context, List<MyEvent> myEventList) {
        this.context = context;
        this.myEventList = myEventList;
    }

    @NonNull
    @Override
    public MyEventViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater inflater = LayoutInflater.from(context);
        View view = inflater.inflate(R.layout.resource_layout_my_events,parent,false);
        return new MyEventViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull MyEventViewHolder holder, int position) {
        MyEvent myEvent = myEventList.get(position);
        holder.txtViewMyEventName.setText(myEvent.getMyEventName());
        holder.txtViewMyEventShortDescription.setText(myEvent.getMyEventDescription());
        Picasso.get().load(myEvent.getAvatarUrl()).fit().centerCrop().into(holder.imgViewMyEvent);
        holder.linearLayoutMyEvent.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Toast.makeText(context,  myEvent.getMyEventName() + " clicked", Toast.LENGTH_SHORT).show();
            }
        });

    }

    @Override
    public int getItemCount() {
        return myEventList.size();
    }

    public class MyEventViewHolder extends RecyclerView.ViewHolder {
        ImageView imgViewMyEvent;
        TextView txtViewMyEventName;
        TextView txtViewMyEventShortDescription;
        LinearLayout linearLayoutMyEvent;

        public MyEventViewHolder(@NonNull View itemView) {
            super(itemView);
            imgViewMyEvent = itemView.findViewById(R.id.imgViewMyEvent);
            txtViewMyEventName = itemView.findViewById(R.id.txtViewMyEventName);
            txtViewMyEventShortDescription = itemView.findViewById(R.id.txtViewMyEventShortDescription);
            linearLayoutMyEvent = itemView.findViewById(R.id.linearLayoutMyEvent);
        }
    }
}
